==> ejc-front-impl-3.0.1-20210729.082737-65-sources.jar: com/ejianc/foundation/front/business/ide/entity/IdeModulePrivate.java <==
package com.ejianc.foundation.front.business.ide.entity;

import java.io.Serializable;
import java.util.Date;

public class IdeModulePrivate implements Serializable {
	private static final long serialVersionUID = -7015845761436474682L;

	private Long id;
	private String code;
	private String name;
	private Long appId;
	private String data;
	private String pageType;
	private Long orgId;
	private String appCode;
	// 是否向下兼容
	private Integer isCompatible;
	// 是否二次开发
	private Integer isDevelopment;
	// js附件id，开发态
	private String attachIdDev;
	// js附件路径，开发态
	private String attachPathDev;
	// js附件id，生产态
	private String attachIdPro;
	// js附件路径，生产态
	private String attachPathPro;
	// js附件审核状态
	private Integer attachVerify;
	// 团队名称
	private String teamName;
	// 应用名称
	private String appName;

	private String orgLevel;

	private Long createId;

	private Date createDate;

	private Integer isDelete;

	private Date modifyDate;

	private Long modifyId;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getData() {
		return data;
	}

	public void setData(String data) {
		this.data = data;
	}

	public String getPageType() {
		return pageType;
	}

	public void setPageType(String pageType) {
		this.pageType = pageType;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getAppCode() {
		return appCode;
	}

	public void setAppCode(String appCode) {
		this.appCode = appCode;
	}

	public Integer getIsCompatible() {
		return isCompatible;
	}

	public void setIsCompatible(Integer isCompatible) {
		this.isCompatible = isCompatible;
	}

	public Integer getIsDevelopment() {
		return isDevelopment;
	}

	public void setIsDevelopment(Integer isDevelopment) {
		this.isDevelopment = isDevelopment;
	}

	public String getAttachIdDev() {
		return attachIdDev;
	}

	public void setAttachIdDev(String attachIdDev) {
		this.attachIdDev = attachIdDev;
	}

	public String getAttachPathDev() {
		return attachPathDev;
	}

	public void setAttachPathDev(String attachPathDev) {
		this.attachPathDev = attachPathDev;
	}

	public String getAttachIdPro() {
		return attachIdPro;
	}

	public void setAttachIdPro(String attachIdPro) {
		this.attachIdPro = attachIdPro;
	}

	public String getAttachPathPro() {
		return attachPathPro;
	}

	public void setAttachPathPro(String attachPathPro) {
		this.attachPathPro = attachPathPro;
	}

	public Integer getAttachVerify() {
		return attachVerify;
	}

	public void setAttachVerify(Integer attachVerify) {
		this.attachVerify = attachVerify;
	}

	public String getTeamName() {
		return teamName;
	}

	public void setTeamName(String teamName) {
		this.teamName = teamName;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getOrgLevel() {
		return orgLevel;
	}

	public void setOrgLevel(String orgLevel) {
		this.orgLevel = orgLevel;
	}

	public Long getCreateId() {
		return createId;
	}

	public void setCreateId(Long createId) {
		this.createId = createId;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Integer getIsDelete() {
		return isDelete;
	}

	public void setIsDelete(Integer isDelete) {
		this.isDelete = isDelete;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Long getModifyId() {
		return modifyId;
	}

	public void setModifyId(Long modifyId) {
		this.modifyId = modifyId;
	}

}

==> ejc-front-impl-3.0.1-20250721.054607-192-sources.jar: com/ejianc/foundation/front/business/ide/entity/IdeModulePrivate.java <==
package com.ejianc.foundation.front.business.ide.entity;

import java.io.Serializable;
import java.util.Date;

public class IdeModulePrivate implements Serializable {
	private static final long serialVersionUID = -7015845761436474682L;

	private Long id;
	private String code;
	private String name;
	private Long appId;
	private String data;
	private String pageType;
	private Long orgId;
	private String appCode;
	// 是否向下兼容
	private Integer isCompatible;
	// 是否二次开发
	private Integer isDevelopment;
	// js附件id，开发态
	private String attachIdDev;
	// js附件路径，开发态
	private String attachPathDev;
	// js附件id，生产态
	private String attachIdPro;
	// js附件路径，生产态
	private String attachPathPro;
	// js附件审核状态
	private Integer attachVerify;
	// 团队名称
	private String teamName;
	// 应用名称
	private String appName;

	private String orgLevel;

	private Long createId;

	private Date createDate;

	private Integer isDelete;

	private Date modifyDate;

	private Long modifyId;

	private String clientType;// pc  mobile

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getData() {
		return data;
	}

	public void setData(String data) {
		this.data = data;
	}

	public String getPageType() {
		return pageType;
	}

	public void setPageType(String pageType) {
		this.pageType = pageType;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getAppCode() {
		return appCode;
	}

	public void setAppCode(String appCode) {
		this.appCode = appCode;
	}

	public Integer getIsCompatible() {
		return isCompatible;
	}

	public void setIsCompatible(Integer isCompatible) {
		this.isCompatible = isCompatible;
	}

	public Integer getIsDevelopment() {
		return isDevelopment;
	}

	public void setIsDevelopment(Integer isDevelopment) {
		this.isDevelopment = isDevelopment;
	}

	public String getAttachIdDev() {
		return attachIdDev;
	}

	public void setAttachIdDev(String attachIdDev) {
		this.attachIdDev = attachIdDev;
	}

	public String getAttachPathDev() {
		return attachPathDev;
	}

	public void setAttachPathDev(String attachPathDev) {
		this.attachPathDev = attachPathDev;
	}

	public String getAttachIdPro() {
		return attachIdPro;
	}

	public void setAttachIdPro(String attachIdPro) {
		this.attachIdPro = attachIdPro;
	}

	public String getAttachPathPro() {
		return attachPathPro;
	}

	public void setAttachPathPro(String attachPathPro) {
		this.attachPathPro = attachPathPro;
	}

	public Integer getAttachVerify() {
		return attachVerify;
	}

	public void setAttachVerify(Integer attachVerify) {
		this.attachVerify = attachVerify;
	}

	public String getTeamName() {
		return teamName;
	}

	public void setTeamName(String teamName) {
		this.teamName = teamName;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getOrgLevel() {
		return orgLevel;
	}

	public void setOrgLevel(String orgLevel) {
		this.orgLevel = orgLevel;
	}

	public Long getCreateId() {
		return createId;
	}

	public void setCreateId(Long createId) {
		this.createId = createId;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Integer getIsDelete() {
		return isDelete;
	}

	public void setIsDelete(Integer isDelete) {
		this.isDelete = isDelete;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Long getModifyId() {
		return modifyId;
	}

	public void setModifyId(Long modifyId) {
		this.modifyId = modifyId;
	}

	public String getClientType() {
		return clientType;
	}

	public void setClientType(String clientType) {
		this.clientType = clientType;
	}
}
